##  Prerequisites
In Jira:
  * A valid Jira instance.
  * Access to the Jira instance to:
    * Generate a personal access token (PAT).
    * Access and configure Jira projects and custom fields.
  * At least one Jira project with work items or epics to sync.
  * If your Jira instance is behind a reverse proxy or API gateway, ensure that API calls from LeanIX services are allowed.


In SAP LeanIX:
  * SAP LeanIX Architecture and Road Map Planning is active.
  * Administrator access to your workspace.
